#
# spec file for package libquvi
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         soname -0_9-0_9_4

Name:           libquvi
Version:        0.9.4
Release:        8.1
Summary:        Library to parse flash media stream URLs
License:        LGPL-2.1-or-later
Group:          System/Libraries
URL:            http://quvi.sourceforge.net/
Source:         http://sourceforge.net/projects/quvi/files/0.9/libquvi/libquvi-0.9.4.tar.xz
Source1:        %{name}.rpmlintrc
# PATCH-FEATURE-OPENSUSE libquvi-stable-build-date.patch sbrabec@suse.cz -- Don't embed build date. Triggers rebuild.
Patch0:         %{name}-stable-build-date.patch
# PATCH-FIX-UPSTREAM marguerite@opensuse.org -- compatibility for lua 5.2+
Patch1:         %{name}-%{version}-lua-5.2.patch
# PATCH-FIX-UPSTREAM libquvi-autoconf-2.70.patch dimstar@opensuse.org -- Fix build with autconfig 2.70
Patch2:         libquvi-autoconf-2.70.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  lua-devel
# For pkgconfig() Provides
BuildRequires:  libgcrypt-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(glib-2.0) >= 2.24
BuildRequires:  pkgconfig(libcurl) >= 7.18.2
BuildRequires:  pkgconfig(libproxy-1.0) >= 0.3.1
BuildRequires:  pkgconfig(libquvi-scripts-0.9) >= 0.9
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
libquvi is a cross-platform library for parsing flash media stream
URLs with C API.

%package -n libquvi%{soname}
Summary:        Library to parse flash media stream URLs
Group:          System/Libraries
Recommends:     libquvi-scripts
# Up to openSUSE 13.2 and SLE 12 *.so files were in the main package. Now it does not exist.
Provides:       libquvi = %{version}-%{release}
Obsoletes:      libquvi < %{version}-%{release}

%description -n libquvi%{soname}
libquvi is a cross-platform library for parsing flash media stream
URLs with C API.

%package devel
Summary:        Library to parse flash media stream URLs -- Development Files
Group:          Development/Libraries/C and C++
Requires:       libquvi%{soname} = %{version}

%description devel
libquvi is a cross-platform library for parsing flash media stream
URLs with C API.

%prep
%setup -q
if test -f %{_sourcedir}/%{name}.changes ; then
%patch -P 0
echo "timestamp for BUILD_TIME" >stamp-build-time
touch -d "$(sed -n '2s/ - .*$//p' <%{_sourcedir}/%{name}.changes)" stamp-build-time
fi
%patch -P 1 -p1
%patch -P 2 -p1

%build
export CFLAGS="%{optflags} -DLUA_COMPAT_MODULE"
autoreconf -f -i
%configure \
    --disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot}%{_libdir} -name '*.la' -type f -delete -print

%post -n libquvi%{soname} -p /sbin/ldconfig

%postun -n libquvi%{soname} -p /sbin/ldconfig

%files -n libquvi%{soname}
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING NEWS README
%{_libdir}/*.so

%files devel
%defattr(-,root,root)
%{_includedir}/quvi-0.9/
#{_libdir}/*.so
%{_libdir}/pkgconfig/libquvi-0.9.pc
%{_mandir}/man3/libquvi.3%{?ext_man}
%{_mandir}/man7/quvi-object.7%{?ext_man}

%changelog
* Fri Mar  1 2024 pgajdos@suse.com
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Apr 22 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Add libquvi-autoconf-2.70.patch: Fix build using autoconf 2.70.
* Wed Jan 27 2021 Callum Farmer <gmbr3@opensuse.org>
- Correct misspelling in libquvi-0.9.4-lua-5.2.patch
* Sat Jul 18 2015 i@marguerite.su
- add patch: libquvi-0.9.4-lua-5.2.patch
  * compatibility w/ lua 5.2+
  * luaL_register replaced by luaL_newlib
* Tue Mar 10 2015 sbrabec@suse.cz
- Move shared library to libquvi%%{soname} to conform to Shared
  Library Packaging Policy and allow parallel installation of more
  versions even without multiversion.
- Use last change date instead of build date.
  libquvi-fake-build-date.patch -> libquvi-stable-build-date.patch
- Add libquvi.rpmlintrc to spec file and update skipped checks.
* Tue Mar 10 2015 pgajdos@suse.com
- no build date [bnc#916338]
  + libquvi-fake-build-date.patch
* Mon Feb 10 2014 dimstar@opensuse.org
- Update to version 0.9.4:
  + API: Return URLs in escaped (percent-encoded) form.
  + m_url_unescaped_form: Check if g_uri_unescape_string fails.
* Mon Oct 21 2013 tchvatal@suse.com
- Version bump to 0.9.3:
  - AC_PREREQ: Bump to 2.69 [c591b1b]
  - API: Add QUVI_OPTION_ALLOW_COOKIES [f56798b]
  - API: Add QUVI_VERSION_SCRIPTS_CONFIGURATION [f0c95e0]
  - API: quvi_version: Read "version" file as ini-file [4466c98]
  - FIX: error: implicit declaration of function 'luaL_register' [f02cc3a]
  - FIX: Unescape input URL before URL resolving [f2ce9b7]
  - quvi.http.cookie: Return unless QUVI_OPTION_ALLOW_COOKIES is QUVI_TRUE [876949e]
* Wed Aug 14 2013 dimstar@opensuse.org
- Update to version 0.9.2:
  + One year of bugfixing and improvements. Please see NEWS for
    a full list of changes.
- Add -DLUA_COMPAT_MODULE to CFLAGS, allowing to use compatibility
  features of LUA 5.1, using LUA 5.2.
- Move the library to libquvi. NOTE: the current library is a .so
  file only and does not have version information. This is an
  intentional behavior from upstream and accepted during the 0.9
  release cycle. The versions are ABI incompatible to each other.
  See http://repo.or.cz/w/libquvi.git/commit/20b1e for a rationale.
- Add libquvi-rpmlintrc: we need to filter out the library being
  in the main package now. rpmlintrc does not know correcly about
  this case, and considering that this is a temporary situation
  during the 0.9 cycle, it's also not worthy to address this in
  rpmlintrc code.
* Sat Dec 29 2012 p.drouand@gmail.com
- Update to 0.4.1 version:
  * Add examples/parse.c [a26f5f6]
  * Add examples/supported.c [179d997]
  * DOC: Replace buzzhumor with gaskrank [3d2e015]
  * FIX: Lua 5.2: Use luaL_newstate instead (#89) [6de7322]
  * FIX: Make verify c/b check against correct option [0c4ff3b]
  * FIX: Use dirname(3) properly [b2f1621]
- Remove conditionnal BuildRequires macros; now work fine with lua 5.2
* Mon Jan 23 2012 vuntz@opensuse.org
- Revert my previous change: libquvi doesn't work with lua 5.2, see
  http://sourceforge.net/apps/trac/quvi/ticket/89
* Tue Jan 17 2012 vuntz@opensuse.org
- Always build against lua-devel: lua 5.2 on 12.2/Factory doesn't
  seem to be an issue.
* Tue Jan 10 2012 vuntz@opensuse.org
- New package (version 0.4.0).
- This is based on the quvi 0.2.19 package: quvi got split in three
  modules upstream for 0.4.x.
